package com.orange.android.brand;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager.NameNotFoundException;
import android.os.SystemProperties;

import com.android.internal.annotations.VisibleForTesting;

public class Brand {
    private static final String BRAND_ORANGE = "orange";
    private static final String COM_ORANGE_COS_PACKAGE_NAME = "com.orange.cos";
    private static Boolean isOrange = null;

    /**
     * Check whether the device ROM is Orange.
     * 
     * @param context
     *            the application environment
     * @return true if the device ROM is Orange, otherwise false.
     */
    public static boolean isOrangeRom(Context context) {
        if (isOrange != null) {
            return isOrange;
        }

        isOrange = isNamedOrange(SystemProperties.get("ro.product.brand"))
                || isNamedOrange(SystemProperties.get("ro.product.brand1"))
                || isSystemApp(context, COM_ORANGE_COS_PACKAGE_NAME);

        return isOrange;
    }

    @VisibleForTesting
    protected static boolean isNamedOrange(String property) {
        return BRAND_ORANGE.equalsIgnoreCase(property);
    }

    @VisibleForTesting
    protected static boolean isSystemApp(Context context, String packageName) {
        boolean isSystemApp = false;

        if (context == null) {
            return isSystemApp;
        }

        PackageInfo pinfo = null;
        try {
            pinfo = context.getPackageManager().getPackageInfo(packageName, 0);
        } catch (NameNotFoundException e) {
            return isSystemApp;
        }
        if (pinfo != null) {
            if ((pinfo.applicationInfo.flags & ApplicationInfo.FLAG_SYSTEM) != 0) {
                isSystemApp = true;
            }
        }

        return isSystemApp;
    }

}